@@ -25,7 +25,7 @@ try:
 except:
     FREEZEGUN_SUPPORT = False
 from itertools import chain
-from attrdict import AttrDict
+from kaniattrdict import AttrDict
 from funcy import project
 
 
